@@ -21,7 +21,7 @@ riskchart <- function(pr, ac, ri=NULL,
 
   # ggplot2 version of the risk chart.
 
-  if (! require(ggplot2)) stop(Rtxt("riskchart requires the ggplot2 package"))
+  if (! requireNamespace("ggplot2")) stop(Rtxt("riskchart requires the ggplot2 package"))
 
   data <- evaluateRisk(pr, ac, ri)
   
@@ -73,13 +73,13 @@ riskchart <- function(pr, ac, ri=NULL,
   # How to get recall.name etc in the following - by default it is not
   # defined?
 
-  p <- ggplot(data, aes(x=100*Caseload))
-  p <- p + scale_colour_manual(breaks=c("Recall", "Risk", "Precision"),
-                               labels=c(recall.name, risk.name, precision.name),
-                               values=c("blue", "forestgreen", "red"))
-  p <- p + scale_linetype_manual(breaks=c("Recall", "Risk", "Precision"),
-                                 labels=c(recall.name, risk.name, precision.name),
-                                 values=c(3, 1, 2))
+  p <- ggplot2::ggplot(data, ggplot2::aes(x=100*Caseload))
+  p <- p + ggplot2::scale_colour_manual(breaks=c("Recall", "Risk", "Precision"),
+                                        labels=c(recall.name, risk.name, precision.name),
+                                        values=c("blue", "forestgreen", "red"))
+  p <- p + ggplot2::scale_linetype_manual(breaks=c("Recall", "Risk", "Precision"),
+                                          labels=c(recall.name, risk.name, precision.name),
+                                          values=c(3, 1, 2))
 
   if (show.maximal)
   {
@@ -88,46 +88,50 @@ riskchart <- function(pr, ac, ri=NULL,
     # productive cases.
     
     mx <- data.frame(x=c(0, 100*data$Precision[1], 100), y=c(0, 100, 100))
-    p <- p + geom_line(data=mx, aes(x, y), colour="grey")
+    p <- p + ggplot2::geom_line(data=mx, ggplot2::aes(x, y), colour="grey")
   }
   
-  p <- p + geom_line(aes(y=100*Recall, colour="Recall", linetype="Recall"))
-  p <- p + geom_line(aes(y=100*Precision, colour="Precision", linetype="Precision"))
-  p <- p + geom_text(data=scores, aes(x=100*pos, y=102, label=ticks), size=2)
+  p <- p + ggplot2::geom_line(ggplot2::aes(y=100*Recall, colour="Recall", linetype="Recall"))
+  p <- p + ggplot2::geom_line(ggplot2::aes(y=100*Precision, colour="Precision", linetype="Precision"))
+  p <- p + ggplot2::geom_text(data=scores, ggplot2::aes(x=100*pos, y=102, label=ticks), size=2)
   p <- p + ggplot2::annotate("text", x=0, y=105, label="Risk Scores", hjust=0, size=3)
-  p <- p + geom_line(aes(y=100*Caseload))
-  p <- p + ggtitle(title) + xlab("Caseload (%)") + ylab("Performance (%)")
-  p <- p + theme(legend.title=element_blank(),
-                 plot.title=element_text(size=10),
+  p <- p + ggplot2::geom_line(ggplot2::aes(y=100*Caseload))
+  p <- p + ggplot2::ggtitle(title) + ggplot2::xlab("Caseload (%)") + ggplot2::ylab("Performance (%)")
+  p <- p + ggplot2::theme(legend.title=ggplot2::element_blank(),
+                 plot.title=ggplot2::element_text(size=10),
                  legend.justification=c(0, 0),
                  legend.position=c(.30, .02))
-  p <- p + guides(colour=guide_legend(keywidth=3, labels=1:3))
-  p <- p + scale_x_continuous(breaks=seq(0, 100, 20))
-  p <- p + scale_y_continuous(breaks=seq(0, 100, 20))
+  p <- p + ggplot2::guides(colour=ggplot2::guide_legend(keywidth=3, labels=1:3))
+  p <- p + ggplot2::scale_x_continuous(breaks=seq(0, 100, 20))
+  p <- p + ggplot2::scale_y_continuous(breaks=seq(0, 100, 20))
   
   if (include.risk)
-    p <- p + geom_line(aes(y=100*Risk, colour="Risk", linetype="Risk"))
+    p <- p + ggplot2::geom_line(ggplot2::aes(y=100*Risk, colour="Risk", linetype="Risk"))
 
   if (include.baseline && show.precision)
-    p <- p + geom_text(data=data.frame(x=100, y=100*data$Precision[1]+4,
+    p <- p + ggplot2::geom_text(data=data.frame(x=100, y=100*data$Precision[1]+4,
                            text=sprintf("%0.0f%%", 100*data$Precision[1])),
-                         aes(x, y, label=text), size=3)
+                         ggplot2::aes(x, y, label=text), size=3)
 
   if (show.lift)
   {
     base.lift <- 100*data$Precision[1]
     lift.seq <- seq(base.lift, 100, base.lift)
     lifts <- data.frame(x=110, y=lift.seq, label=lift.seq/base.lift)
-    p <- p + geom_text(data=lifts, aes(x, y, label=label), size=3)
-    p <- p + geom_text(aes(x=110, y=101.5, label="Lift"), size=3)
+    # 140906 R-Devel CMD check complains label not defined in:
+    # p <- p + ggplot2::geom_text(data=lifts, ggplot2::aes(x, y, label=label), size=3)
+    # So use aes_string
+    p <- p + ggplot2::geom_text(data=lifts,
+                                ggplot2::aes_string("x", "y", label="label"), size=3)
+    p <- p + ggplot2::geom_text(ggplot2::aes(x=110, y=101.5, label="Lift"), size=3)
   }
 
   if (! is.null(thresholds))
-    p <- p + geom_vline(xintercept=100*locateScores(thresholds),
+    p <- p + ggplot2::geom_vline(xintercept=100*locateScores(thresholds),
                         linetype="twodash", color="grey")
 
-  p <- p + theme(legend.background=element_rect(fill=NA),
-                 legend.key=element_rect(fill=NA, linetype=0))
+  p <- p + ggplot2::theme(legend.background=ggplot2::element_rect(fill=NA),
+                 legend.key=ggplot2::element_rect(fill=NA, linetype=0))
   
   return(p)
 }
